@@ -9,11 +9,13 @@ use warnings;
 use Readonly;
 
 # Constants.
-Readonly::Array our @EXPORT_OK => qw(err_bt_pretty err_bt_pretty_rev err_line err_line_all);
-Readonly::Scalar my $SPACE => q{ };
+Readonly::Array our @EXPORT_OK => qw(err_bt_pretty err_bt_pretty_rev err_line
+	err_line_all err_print err_print_var);
+Readonly::Scalar our $EMPTY_STR => q{};
+Readonly::Scalar our $SPACE => q{ };
 
 # Version.
-our $VERSION = 0.20;
+our $VERSION = 0.21;
 
 # Pretty print of backtrace.
 sub err_bt_pretty {
@@ -37,6 +39,12 @@ sub err_bt_pretty_rev {
 	return wantarray ? @ret : (join "\n", @ret)."\n";
 }
 
+# Pretty print line error.
+sub err_line {
+	my @errors = @_;
+	return _err_line($errors[-1]);
+}
+
 # Pretty print with errors each on one line.
 sub err_line_all {
 	my @errors = @_;
@@ -47,20 +55,72 @@ sub err_line_all {
 	return $ret;
 }
 
-# Pretty print line error.
-sub err_line {
+# Print error.
+sub err_print {
 	my @errors = @_;
-	return _err_line($errors[-1]);
+	my $class = _err_class($errors[-1]);
+	return $class.$errors[-1]->{'msg'}->[0];
+}
+
+# Print error with all variables.
+sub err_print_var {
+	my @errors = @_;
+	my @msg = @{$errors[-1]->{'msg'}};
+	my $class = _err_class($errors[-1]);
+	my @ret = ($class.(shift @msg));
+	push @ret, _err_variables(@msg);
+	return wantarray ? @ret : (join "\n", @ret)."\n";
 }
 
 # Pretty print one error backtrace helper.
 sub _bt_pretty_one {
 	my ($error_hr, $l_ar) = @_;
-	my @ret;
 	my @msg = @{$error_hr->{'msg'}};
-	my $e = shift @msg;
+	my @ret = ('ERROR: '.(shift @msg));
+	push @ret, _err_variables(@msg);
+	foreach my $i (0 .. $#{$error_hr->{'stack'}}) {
+		my $st = $error_hr->{'stack'}->[$i];
+		my $ret = $st->{'class'};
+		$ret .=  $SPACE x ($l_ar->[0] - length $st->{'class'});
+		$ret .=  $st->{'sub'};
+		$ret .=  $SPACE x ($l_ar->[1] - length $st->{'sub'});
+		$ret .=  $st->{'prog'};
+		$ret .=  $SPACE x ($l_ar->[2] - length $st->{'prog'});
+		$ret .=  $st->{'line'};
+		push @ret, $ret;
+	}
+	return @ret;
+}
+
+# Print class if class isn't main.
+sub _err_class {
+	my $error_hr = shift;
+	my $class = $error_hr->{'stack'}->[0]->{'class'};
+	if ($class eq 'main') {
+		$class = $EMPTY_STR;
+	}
+	if ($class) {
+		$class .= ': ';
+	}
+	return $class;
+}
+
+# Pretty print line error.
+sub _err_line {
+	my $error_hr = shift;
+	my $stack_ar = $error_hr->{'stack'};
+	my $msg = $error_hr->{'msg'};
+	my $prog = $stack_ar->[0]->{'prog'};
+	$prog =~ s/^\.\///gms;
+	my $e = $msg->[0];
 	chomp $e;
-	push @ret, 'ERROR: '.$e;
+	return "#Error [$prog:$stack_ar->[0]->{'line'}] $e\n";
+}
+
+# Process variables.
+sub _err_variables {
+	my @msg = @_;
+	my @ret;
 	while (@msg) {
 		my $f = shift @msg;
 		my $t = shift @msg;
@@ -75,17 +135,6 @@ sub _bt_pretty_one {
 		}
 		push @ret, $ret;
 	}
-	foreach my $i (0 .. $#{$error_hr->{'stack'}}) {
-		my $st = $error_hr->{'stack'}->[$i];
-		my $ret = $st->{'class'};
-		$ret .=  $SPACE x ($l_ar->[0] - length $st->{'class'});
-		$ret .=  $st->{'sub'};
-		$ret .=  $SPACE x ($l_ar->[1] - length $st->{'sub'});
-		$ret .=  $st->{'prog'};
-		$ret .=  $SPACE x ($l_ar->[2] - length $st->{'prog'});
-		$ret .=  $st->{'line'};
-		push @ret, $ret;
-	}
 	return @ret;
 }
 
@@ -112,18 +161,6 @@ sub _lenghts {
 	return $l_ar;
 }
 
-# Pretty print line error.
-sub _err_line {
-	my $error_hr = shift;
-	my $stack_ar = $error_hr->{'stack'};
-	my $msg = $error_hr->{'msg'};
-	my $prog = $stack_ar->[0]->{'prog'};
-	$prog =~ s/^\.\///gms;
-	my $e = $msg->[0];
-	chomp $e;
-	return "#Error [$prog:$stack_ar->[0]->{'line'}] $e\n";
-}
-
 1;
 
 __END__
@@ -138,11 +175,17 @@ Error::Pure::Output::Text - Output subroutines for Error::Pure.
 
 =head1 SYNOPSIS
 
- use Error::Pure::Output::Text qw(err_bt_pretty err_bt_pretty_rev err_line err_line_all);
- print err_bt_pretty(@errors);
- print err_bt_pretty_rev(@errors);
- print err_line_all(@errors);
- print err_line(@errors);
+ use Error::Pure::Output::Text qw(err_bt_pretty err_bt_pretty_rev err_line
+         err_line_all err_print err_print_var);
+ my $ret = err_bt_pretty(@errors);
+ my @ret = err_bt_pretty(@errors);
+ my $ret = err_bt_pretty_rev(@errors);
+ my @ret = err_bt_pretty_rev(@errors);
+ my $ret = err_line(@errors);
+ my $ret = err_line_all(@errors);
+ my $ret = err_print(@errors);
+ my $ret = err_print_var(@errors);
+ my @ret = err_print_var(@errors);
 
 =head1 SUBROUTINES
 
@@ -181,6 +224,13 @@ Error::Pure::Output::Text - Output subroutines for Error::Pure.
          ...
          sub, caller, program, line
 
+=item C<err_line(@errors)>
+
+ Returns string with error on one line.
+ Use last error in @errors structure..
+ Format of error is: "#Error [%s:%s] %s\n"
+ Values of error are: $program, $line, $message
+
 =item C<err_line_all(@errors)>
 
  Returns string with errors each on one line.
@@ -188,12 +238,17 @@ Error::Pure::Output::Text - Output subroutines for Error::Pure.
  Format of error line is: "#Error [%s:%s] %s\n"
  Values of error line are: $program, $line, $message
 
-=item C<err_line(@errors)>
+=item C<err_print(@errors)>
 
- Returns string with error on one line.
- Use last error in @errors structure..
- Format of error is: "#Error [%s:%s] %s\n"
- Values of error are: $program, $line, $message
+ Print first error.
+ If error comes from class, print class name before error.
+ Returns string with error.
+
+=item C<err_print_var(@errors)>
+
+ Print first error with all variables.
+ Returns error string in scalar mode.
+ Returns lines of error in array mode.
 
 =back
 
@@ -441,6 +496,125 @@ Error::Pure::Output::Text - Output subroutines for Error::Pure.
  # main  err         script.pl  1
  # main  eval {...}  script.pl  20
 
+=head1 EXAMPLE6
+
+ # Pragmas.
+ use strict;
+ use warnings;
+
+ # Modules.
+ use Error::Pure::Output::Text qw(err_print);
+
+ # Fictional error structure.
+ my $err_hr = {
+         'msg' => [
+                 'FOO',
+                 'BAR',
+         ],
+         'stack' => [
+                 {
+                         'args' => '(2)',
+                         'class' => 'main',
+                         'line' => 1,
+                         'prog' => 'script.pl',
+                         'sub' => 'err',
+                 }, {
+                         'args' => '',
+                         'class' => 'main',
+                         'line' => 20,
+                         'prog' => 'script.pl',
+                         'sub' => 'eval {...}',
+                 }
+         ],
+ };
+
+ # Print out.
+ print err_print($err_hr)."\n";
+
+ # Output:
+ # FOO
+
+=head1 EXAMPLE7
+
+ # Pragmas.
+ use strict;
+ use warnings;
+
+ # Modules.
+ use Error::Pure::Output::Text qw(err_print);
+
+ # Fictional error structure.
+ my $err_hr = {
+         'msg' => [
+                 'FOO',
+                 'BAR',
+         ],
+         'stack' => [
+                 {
+                         'args' => '(2)',
+                         'class' => 'Class',
+                         'line' => 1,
+                         'prog' => 'script.pl',
+                         'sub' => 'err',
+                 }, {
+                         'args' => '',
+                         'class' => 'mains',
+                         'line' => 20,
+                         'prog' => 'script.pl',
+                         'sub' => 'eval {...}',
+                 }
+         ],
+ };
+
+ # Print out.
+ print err_print($err_hr)."\n";
+
+ # Output:
+ # Class: FOO
+
+=head1 EXAMPLE8
+
+ # Pragmas.
+ use strict;
+ use warnings;
+
+ # Modules.
+ use Error::Pure::Output::Text qw(err_print_var);
+
+ # Fictional error structure.
+ my $err_hr = {
+         'msg' => [
+                 'FOO',
+                 'KEY1',
+                 'VALUE1',
+                 'KEY2',
+                 'VALUE2',
+         ],
+         'stack' => [
+                 {
+                         'args' => '(2)',
+                         'class' => 'main',
+                         'line' => 1,
+                         'prog' => 'script.pl',
+                         'sub' => 'err',
+                 }, {
+                         'args' => '',
+                         'class' => 'main',
+                         'line' => 20,
+                         'prog' => 'script.pl',
+                         'sub' => 'eval {...}',
+                 }
+         ],
+ };
+
+ # Print out.
+ print scalar err_print_var($err_hr);
+
+ # Output:
+ # ERROR: FOO
+ # KEY1: VALUE1
+ # KEY2: VALUE2
+
 =head1 DEPENDENCIES
 
 L<Exporter>,
@@ -472,6 +646,6 @@ BSD 2-Clause License
 
 =head1 VERSION
 
-0.20
+0.21
 
 =cut
